Function rename

async fn rename<impl AsRef<Path>: AsRef<std::path::Path>, impl AsRef<Path>: AsRef<std::path::Path>>(from: impl AsRef<Path>, to: impl AsRef<Path>) -> Result<()>

Renames a file or directory to a new name, replacing the original file if to already exists.

This will not work if the new name is on a different mount point.

This is an async version of std::fs::rename.