Function try_exists
async fn try_exists<impl AsRef<Path>: AsRef<std::path::Path>>(path: impl AsRef<Path>) -> Result<bool>
Returns Ok(true) if the path points at an existing entity.
This function will traverse symbolic links to query information about the
destination file. In case of broken symbolic links this will return Ok(false).
This is the async equivalent of std::path::Path::try_exists.
Examples
use tokio::fs;
# async fn dox() -> std::io::Result<()> {
fs::try_exists("foo.txt").await?;
# Ok(())
# }