Struct ReuniteError

struct ReuniteError(2506, 2507)

Error indicating that two halves were not from the same socket, and thus could not be reunited.

Implementations

impl Debug for ReuniteError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for ReuniteError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for ReuniteError

impl Freeze for ReuniteError

impl RefUnwindSafe for ReuniteError

impl Send for ReuniteError

impl Sync for ReuniteError

impl Unpin for ReuniteError

impl UnsafeUnpin for ReuniteError

impl UnwindSafe for ReuniteError

impl<T> Any for ReuniteError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ReuniteError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ReuniteError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ReuniteError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for ReuniteError

fn to_string(self: &Self) -> String

impl<T, U> Into for ReuniteError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ReuniteError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ReuniteError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>