Struct SocketAddr

struct SocketAddr(_)

An address associated with a Tokio Unix socket.

This type is a thin wrapper around std::os::unix::net::SocketAddr. You can convert to and from the standard library SocketAddr type using the From trait.

Implementations

impl SocketAddr

fn is_unnamed(self: &Self) -> bool

Returns true if the address is unnamed.

Documentation reflected in SocketAddr

fn as_pathname(self: &Self) -> Option<&Path>

Returns the contents of this address if it is a pathname address.

Documentation reflected in SocketAddr

impl Clone for SocketAddr

fn clone(self: &Self) -> SocketAddr

impl Debug for SocketAddr

fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result

impl Freeze for SocketAddr

impl From for SocketAddr

fn from(value: SocketAddr) -> Self

impl RefUnwindSafe for SocketAddr

impl Send for SocketAddr

impl Sync for SocketAddr

impl Unpin for SocketAddr

impl UnsafeUnpin for SocketAddr

impl UnwindSafe for SocketAddr

impl<T> Any for SocketAddr

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SocketAddr

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SocketAddr

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SocketAddr

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SocketAddr

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SocketAddr

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SocketAddr

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SocketAddr

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SocketAddr

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>