Struct EnterGuard

struct EnterGuard<'a> { ... }

Runtime context guard.

Returned by Runtime::enter and Handle::enter, the context guard exits the runtime context on drop.

Implementations

impl<'a> Debug for EnterGuard<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for EnterGuard<'a>

impl<'a> RefUnwindSafe for EnterGuard<'a>

impl<'a> Send for EnterGuard<'a>

impl<'a> Sync for EnterGuard<'a>

impl<'a> Unpin for EnterGuard<'a>

impl<'a> UnsafeUnpin for EnterGuard<'a>

impl<'a> UnwindSafe for EnterGuard<'a>

impl<T> Any for EnterGuard<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for EnterGuard<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for EnterGuard<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for EnterGuard<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for EnterGuard<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for EnterGuard<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for EnterGuard<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>