Struct TryCurrentError

struct TryCurrentError { ... }

Error returned by try_current when no Runtime has been started

Implementations

impl TryCurrentError

fn is_missing_context(self: &Self) -> bool

Returns true if the call failed because there is currently no runtime in the Tokio context.

fn is_thread_local_destroyed(self: &Self) -> bool

Returns true if the call failed because the Tokio context thread-local had been destroyed. This can usually only happen if in the destructor of other thread-locals.

impl Debug for TryCurrentError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for TryCurrentError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for TryCurrentError

impl Freeze for TryCurrentError

impl RefUnwindSafe for TryCurrentError

impl Send for TryCurrentError

impl Sync for TryCurrentError

impl Unpin for TryCurrentError

impl UnsafeUnpin for TryCurrentError

impl UnwindSafe for TryCurrentError

impl<T> Any for TryCurrentError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TryCurrentError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TryCurrentError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for TryCurrentError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for TryCurrentError

fn to_string(self: &Self) -> String

impl<T, U> Into for TryCurrentError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TryCurrentError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TryCurrentError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>