pub enum TryRecvError {
Empty,
Closed,
Lagged(u64),
}Variants
Empty
The channel is currently empty. There are still active
Sender handles, so data may yet become available.
Closed
There are no more active senders implying no further messages will ever be sent.
Lagged(u64)
The receiver lagged too far behind: one or more messages were overwritten in the ring buffer before this receiver could read them.
The receiver remains subscribed. Its internal cursor has been advanced
to the oldest message still retained by the channel; the next
successful try_recv call returns that message (unless further sends
overwrite it first).
The u64 is the number of messages that were skipped (dropped before
the receiver’s previous cursor position).