Struct AcquireError

struct AcquireError(_)

Error returned from the Semaphore::acquire function.

An acquire operation can only fail if the semaphore has been closed.

Implementations

impl Debug for AcquireError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for AcquireError

fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result

impl Error for AcquireError

impl Freeze for AcquireError

impl RefUnwindSafe for AcquireError

impl Send for AcquireError

impl Sync for AcquireError

impl Unpin for AcquireError

impl UnsafeUnpin for AcquireError

impl UnwindSafe for AcquireError

impl<T> Any for AcquireError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AcquireError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AcquireError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for AcquireError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for AcquireError

fn to_string(self: &Self) -> String

impl<T, U> Into for AcquireError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AcquireError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AcquireError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>