Struct RwLockWriteGuard
struct RwLockWriteGuard<'a, T: ?Sized> { ... }
RAII structure used to release the exclusive write access of a lock when dropped.
Implementations
impl<'a, T: ?Sized> RwLockWriteGuard<'a, T>
fn map<F, U: ?Sized>(this: Self, f: F) -> RwLockMappedWriteGuard<'a, U> where F: FnOnce(&mut T) -> &mut UMakes a new
RwLockMappedWriteGuardfor a component of the locked data.This operation cannot fail as the
RwLockWriteGuardpassed in already locked the data.This is an associated function that needs to be used as
RwLockWriteGuard::map(..). A method would interfere with methods of the same name on the contents of the locked data.This is an asynchronous version of
RwLockWriteGuard::mapfrom theparking_lotcrate.Examples
use ; ; # # asyncfn downgrade_map<F, U: ?Sized>(this: Self, f: F) -> RwLockReadGuard<'a, U> where F: FnOnce(&T) -> &UMakes a new
RwLockReadGuardfor a component of the locked data.This operation cannot fail as the
RwLockWriteGuardpassed in already locked the data.This is an associated function that needs to be used as
RwLockWriteGuard::downgrade_map(..). A method would interfere with methods of the same name on the contents of the locked data.This is equivalent to a combination of asynchronous
RwLockWriteGuard::mapandRwLockWriteGuard::downgradefrom theparking_lotcrate.Inside of
f, you retain exclusive access to the data, despite only being given a&T. Handing out a&mut Twould result in unsoundness, as you could use interior mutability.Examples
use ; ; # # asyncfn try_map<F, U: ?Sized>(this: Self, f: F) -> Result<RwLockMappedWriteGuard<'a, U>, Self> where F: FnOnce(&mut T) -> Option<&mut U>Attempts to make a new
RwLockMappedWriteGuardfor a component of the locked data. The original guard is returned if the closure returnsNone.This operation cannot fail as the
RwLockWriteGuardpassed in already locked the data.This is an associated function that needs to be used as
RwLockWriteGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.This is an asynchronous version of
RwLockWriteGuard::try_mapfrom theparking_lotcrate.Examples
use ; ; # # asyncfn try_downgrade_map<F, U: ?Sized>(this: Self, f: F) -> Result<RwLockReadGuard<'a, U>, Self> where F: FnOnce(&T) -> Option<&U>Attempts to make a new
RwLockReadGuardfor a component of the locked data. The original guard is returned if the closure returnsNone.This operation cannot fail as the
RwLockWriteGuardpassed in already locked the data.This is an associated function that needs to be used as
RwLockWriteGuard::try_downgrade_map(...). A method would interfere with methods of the same name on the contents of the locked data.This is equivalent to a combination of asynchronous
RwLockWriteGuard::try_mapandRwLockWriteGuard::downgradefrom theparking_lotcrate.Inside of
f, you retain exclusive access to the data, despite only being given a&T. Handing out a&mut Twould result in unsoundness, as you could use interior mutability.If this function returns
Err(...), the lock is never unlocked nor downgraded.Examples
use ; ; # # asyncfn into_mapped(this: Self) -> RwLockMappedWriteGuard<'a, T>Converts this
RwLockWriteGuardinto anRwLockMappedWriteGuard. This method can be used to store a non-mapped guard in a struct field that expects a mapped guard.This is equivalent to calling
RwLockWriteGuard::map(guard, |me| me).fn downgrade(self: Self) -> RwLockReadGuard<'a, T>Atomically downgrades a write lock into a read lock without allowing any writers to take exclusive access of the lock in the meantime.
Note: This won't necessarily allow any additional readers to acquire locks, since
RwLockis fair and it is possible that a writer is next in line.Returns an RAII guard which will drop this read access of the
RwLockwhen dropped.Examples
# use RwLock; # use Arc; # # # async
impl<'a, T> Debug for RwLockWriteGuard<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, T> Display for RwLockWriteGuard<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, T> Freeze for RwLockWriteGuard<'a, T>
impl<'a, T> RefUnwindSafe for RwLockWriteGuard<'a, T>
impl<'a, T> Unpin for RwLockWriteGuard<'a, T>
impl<'a, T> UnsafeUnpin for RwLockWriteGuard<'a, T>
impl<'a, T> UnwindSafe for RwLockWriteGuard<'a, T>
impl<'a, T: ?Sized> Drop for RwLockWriteGuard<'a, T>
fn drop(self: &mut Self)
impl<P, T> Receiver for RwLockWriteGuard<'a, T>
impl<T> Any for RwLockWriteGuard<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RwLockWriteGuard<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RwLockWriteGuard<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for RwLockWriteGuard<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Send for RwLockWriteGuard<'_, T>
impl<T> Sync for RwLockWriteGuard<'_, T>
impl<T> ToString for RwLockWriteGuard<'a, T>
fn to_string(self: &Self) -> String
impl<T, U> Into for RwLockWriteGuard<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RwLockWriteGuard<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RwLockWriteGuard<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized> Deref for RwLockWriteGuard<'_, T>
fn deref(self: &Self) -> &T
impl<T: ?Sized> DerefMut for RwLockWriteGuard<'_, T>
fn deref_mut(self: &mut Self) -> &mut T