Struct Error

struct Error(_)

Errors encountered by the timer implementation.

Currently, there are two different errors that can occur:

Implementations

impl Error

fn shutdown() -> Error

Creates an error representing a shutdown timer.

fn is_shutdown(self: &Self) -> bool

Returns true if the error was caused by the timer being shutdown.

fn at_capacity() -> Error

Creates an error representing a timer at capacity.

fn is_at_capacity(self: &Self) -> bool

Returns true if the error was caused by the timer being at capacity.

fn invalid() -> Error

Creates an error representing a misconfigured timer.

fn is_invalid(self: &Self) -> bool

Returns true if the error was caused by the timer being misconfigured.

impl Clone for Error

fn clone(self: &Self) -> Error

impl Copy for Error

impl Debug for Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Error

fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result

impl Error for Error

impl Freeze for Error

impl RefUnwindSafe for Error

impl Send for Error

impl Sync for Error

impl Unpin for Error

impl UnsafeUnpin for Error

impl UnwindSafe for Error

impl<T> Any for Error

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Error

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Error

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Error

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Error

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Error

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for Error

fn to_string(self: &Self) -> String

impl<T, U> Into for Error

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Error

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Error

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>