Struct tokio::time::Interval [−][src]
pub struct Interval { /* fields omitted */ }Expand description
Interval returned by interval and interval_at.
This type allows you to wait on a sequence of instants with a certain
duration between each instant. Unlike calling sleep in a loop, this lets
you count the time spent between the calls to sleep as well.
An Interval can be turned into a Stream with IntervalStream.
Implementations
Completes when the next instant in the interval has been reached.
Cancel safety
This method is cancellation safe. If tick is used as the branch in a tokio::select! and
another branch completes first, then no tick has been consumed.
Examples
use tokio::time;
use std::time::Duration;
#[tokio::main]
async fn main() {
let mut interval = time::interval(Duration::from_millis(10));
interval.tick().await;
interval.tick().await;
interval.tick().await;
// approximately 20ms have elapsed.
}Polls for the next instant in the interval to be reached.
This method can return the following values:
Poll::Pendingif the next instant has not yet been reached.Poll::Ready(instant)if the next instant has been reached.
When this method returns Poll::Pending, the current task is scheduled
to receive a wakeup when the instant has elapsed. Note that on multiple
calls to poll_tick, only the Waker from the
Context passed to the most recent call is scheduled to receive a
wakeup.
Resets the interval to complete one period after the current time.
This method ignores MissedTickBehavior strategy.
Examples
use tokio::time;
use std::time::Duration;
#[tokio::main]
async fn main() {
let mut interval = time::interval(Duration::from_millis(100));
interval.tick().await;
time::sleep(Duration::from_millis(50)).await;
interval.reset();
interval.tick().await;
interval.tick().await;
// approximately 250ms have elapsed.
}Returns the MissedTickBehavior strategy currently being used.
Sets the MissedTickBehavior strategy that should be used.