Struct DirEntry

struct DirEntry { ... }

Entries returned by the ReadDir stream.

This is a specialized version of std::fs::DirEntry for usage from the Tokio runtime.

An instance of DirEntry represents an entry inside of a directory on the filesystem. Each entry can be inspected via methods to learn about the full path or possibly other metadata through per-platform extension traits.

Implementations

impl DirEntry

fn ino(self: &Self) -> u64

Returns the underlying d_ino field in the contained dirent structure.

Examples

use tokio::fs;

# #[tokio::main]
# async fn main() -> std::io::Result<()> {
let mut entries = fs::read_dir(".").await?;
while let Some(entry) = entries.next_entry().await? {
    // Here, `entry` is a `DirEntry`.
    println!("{:?}: {}", entry.file_name(), entry.ino());
}
# Ok(())
# }

impl DirEntry

fn path(self: &Self) -> PathBuf

Returns the full path to the file that this entry represents.

The full path is created by joining the original path to read_dir with the filename of this entry.

Examples

use tokio::fs;

# async fn dox() -> std::io::Result<()> {
let mut entries = fs::read_dir(".").await?;

while let Some(entry) = entries.next_entry().await? {
    println!("{:?}", entry.path());
}
# Ok(())
# }

This prints output like:

"./whatever.txt"
"./foo.html"
"./hello_world.rs"

The exact text, of course, depends on what files you have in ..

fn file_name(self: &Self) -> OsString

Returns the bare file name of this directory entry without any other leading path component.

Examples

use tokio::fs;

# async fn dox() -> std::io::Result<()> {
let mut entries = fs::read_dir(".").await?;

while let Some(entry) = entries.next_entry().await? {
    println!("{:?}", entry.file_name());
}
# Ok(())
# }
async fn metadata(self: &Self) -> Result<Metadata>

Returns the metadata for the file that this entry points at.

This function will not traverse symlinks if this entry points at a symlink.

Platform-specific behavior

On Windows this function is cheap to call (no extra system calls needed), but on Unix platforms this function is the equivalent of calling symlink_metadata on the path.

Examples

use tokio::fs;

# async fn dox() -> std::io::Result<()> {
let mut entries = fs::read_dir(".").await?;

while let Some(entry) = entries.next_entry().await? {
    if let Ok(metadata) = entry.metadata().await {
        // Now let's show our entry's permissions!
        println!("{:?}: {:?}", entry.path(), metadata.permissions());
    } else {
        println!("Couldn't get file type for {:?}", entry.path());
    }
}
# Ok(())
# }
async fn file_type(self: &Self) -> Result<FileType>

Returns the file type for the file that this entry points at.

This function will not traverse symlinks if this entry points at a symlink.

Platform-specific behavior

On Windows and most Unix platforms this function is free (no extra system calls needed), but some Unix platforms may require the equivalent call to symlink_metadata to learn about the target file type.

Examples

use tokio::fs;

# async fn dox() -> std::io::Result<()> {
let mut entries = fs::read_dir(".").await?;

while let Some(entry) = entries.next_entry().await? {
    if let Ok(file_type) = entry.file_type().await {
        // Now let's show our entry's file type!
        println!("{:?}: {:?}", entry.path(), file_type);
    } else {
        println!("Couldn't get file type for {:?}", entry.path());
    }
}
# Ok(())
# }

impl Debug for DirEntry

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for DirEntry

impl RefUnwindSafe for DirEntry

impl Send for DirEntry

impl Sync for DirEntry

impl Unpin for DirEntry

impl UnsafeUnpin for DirEntry

impl UnwindSafe for DirEntry

impl<T> Any for DirEntry

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DirEntry

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DirEntry

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DirEntry

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DirEntry

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DirEntry

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DirEntry

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>