Struct File
struct File { ... }
A reference to an open file on the filesystem.
This is a specialized version of std::fs::File for usage from the
Tokio runtime.
An instance of a File can be read and/or written depending on what options
it was opened with. Files also implement AsyncSeek to alter the logical
cursor that the file contains internally.
A file will not be closed immediately when it goes out of scope if there
are any IO operations that have not yet completed. To ensure that a file is
closed immediately when it is dropped, you should call flush before
dropping it. Note that this does not ensure that the file has been fully
written to disk; the operating system might keep the changes around in an
in-memory buffer. See the sync_all method for telling the OS to write
the data to disk.
Reading and writing to a File is usually done using the convenience
methods found on the AsyncReadExt and AsyncWriteExt traits.
Examples
Create a new file and asynchronously write bytes to it:
use tokio::fs::File;
use tokio::io::AsyncWriteExt; // for write_all()
# async fn dox() -> std::io::Result<()> {
let mut file = File::create("foo.txt").await?;
file.write_all(b"hello, world!").await?;
# Ok(())
# }
Read the contents of a file into a buffer:
use tokio::fs::File;
use tokio::io::AsyncReadExt; // for read_to_end()
# async fn dox() -> std::io::Result<()> {
let mut file = File::open("foo.txt").await?;
let mut contents = vec![];
file.read_to_end(&mut contents).await?;
println!("len = {}", contents.len());
# Ok(())
# }
Implementations
impl File
async fn open<impl AsRef<Path>: AsRef<Path>>(path: impl AsRef<Path>) -> Result<File>Attempts to open a file in read-only mode.
See
OpenOptionsfor more details.Errors
This function will return an error if called from outside of the Tokio runtime or if path does not already exist. Other errors may also be returned according to
OpenOptions::open.Examples
use tokio::fs::File; use tokio::io::AsyncReadExt; # async fn dox() -> std::io::Result<()> { let mut file = File::open("foo.txt").await?; let mut contents = vec![]; file.read_to_end(&mut contents).await?; println!("len = {}", contents.len()); # Ok(()) # }The
read_to_endmethod is defined on theAsyncReadExttrait.async fn create<impl AsRef<Path>: AsRef<Path>>(path: impl AsRef<Path>) -> Result<File>Opens a file in write-only mode.
This function will create a file if it does not exist, and will truncate it if it does.
See
OpenOptionsfor more details.Errors
Results in an error if called from outside of the Tokio runtime or if the underlying
createcall results in an error.Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::create("foo.txt").await?; file.write_all(b"hello, world!").await?; # Ok(()) # }The
write_allmethod is defined on theAsyncWriteExttrait.async fn create_new<P: AsRef<Path>>(path: P) -> Result<File>Opens a file in read-write mode.
This function will create a file if it does not exist, or return an error if it does. This way, if the call succeeds, the file returned is guaranteed to be new.
This option is useful because it is atomic. Otherwise between checking whether a file exists and creating a new one, the file may have been created by another process (a TOCTOU race condition / attack).
This can also be written using
File::options().read(true).write(true).create_new(true).open(...).See
OpenOptionsfor more details.Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::create_new("foo.txt").await?; file.write_all(b"hello, world!").await?; # Ok(()) # }The
write_allmethod is defined on theAsyncWriteExttrait.fn options() -> OpenOptionsReturns a new
OpenOptionsobject.This function returns a new
OpenOptionsobject that you can use to open or create a file with specific options ifopen()orcreate()are not appropriate.It is equivalent to
OpenOptions::new(), but allows you to write more readable code. Instead ofOpenOptions::new().append(true).open("example.log"), you can writeFile::options().append(true).open("example.log"). This also avoids the need to importOpenOptions.See the
OpenOptions::newfunction for more details.Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut f = File::options().append(true).open("example.log").await?; f.write_all(b"new line\n").await?; # Ok(()) # }fn from_std(std: StdFile) -> FileConverts a
std::fs::Fileto atokio::fs::File.Examples
// This line could block. It is not recommended to do this on the Tokio // runtime. let std_file = std::fs::File::open("foo.txt").unwrap(); let file = tokio::fs::File::from_std(std_file);async fn sync_all(self: &Self) -> Result<()>Attempts to sync all OS-internal metadata to disk.
This function will attempt to ensure that all in-core data reaches the filesystem before returning.
Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::create("foo.txt").await?; file.write_all(b"hello, world!").await?; file.sync_all().await?; # Ok(()) # }The
write_allmethod is defined on theAsyncWriteExttrait.async fn sync_data(self: &Self) -> Result<()>This function is similar to
sync_all, except that it may not synchronize file metadata to the filesystem.This is intended for use cases that must synchronize content, but don't need the metadata on disk. The goal of this method is to reduce disk operations.
Note that some platforms may simply implement this in terms of
sync_all.Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::create("foo.txt").await?; file.write_all(b"hello, world!").await?; file.sync_data().await?; # Ok(()) # }The
write_allmethod is defined on theAsyncWriteExttrait.async fn set_len(self: &Self, size: u64) -> Result<()>Truncates or extends the underlying file, updating the size of this file to become size.
If the size is less than the current file's size, then the file will be shrunk. If it is greater than the current file's size, then the file will be extended to size and have all of the intermediate data filled in with 0s.
Errors
This function will return an error if the file is not opened for writing.
Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::create("foo.txt").await?; file.write_all(b"hello, world!").await?; file.set_len(10).await?; # Ok(()) # }The
write_allmethod is defined on theAsyncWriteExttrait.async fn metadata(self: &Self) -> Result<Metadata>Queries metadata about the underlying file.
Examples
use tokio::fs::File; # async fn dox() -> std::io::Result<()> { let file = File::open("foo.txt").await?; let metadata = file.metadata().await?; println!("{:?}", metadata); # Ok(()) # }async fn try_clone(self: &Self) -> Result<File>Creates a new
Fileinstance that shares the same underlying file handle as the existingFileinstance. Reads, writes, and seeks will affect both File instances simultaneously.Examples
use tokio::fs::File; # async fn dox() -> std::io::Result<()> { let file = File::open("foo.txt").await?; let file_clone = file.try_clone().await?; # Ok(()) # }async fn into_std(self: Self) -> StdFileDestructures
Fileinto astd::fs::File. This function is async to allow any in-flight operations to complete.Use
File::try_into_stdto attempt conversion immediately.Examples
use tokio::fs::File; # async fn dox() -> std::io::Result<()> { let tokio_file = File::open("foo.txt").await?; let std_file = tokio_file.into_std().await; # Ok(()) # }fn try_into_std(self: Self) -> Result<StdFile, Self>Tries to immediately destructure
Fileinto astd::fs::File.Errors
This function will return an error containing the file if some operation is in-flight.
Examples
use tokio::fs::File; # async fn dox() -> std::io::Result<()> { let tokio_file = File::open("foo.txt").await?; let std_file = tokio_file.try_into_std().unwrap(); # Ok(()) # }async fn set_permissions(self: &Self, perm: Permissions) -> Result<()>Changes the permissions on the underlying file.
Platform-specific behavior
This function currently corresponds to the
fchmodfunction on Unix and theSetFileInformationByHandlefunction on Windows. Note that, this may change in the future.Errors
This function will return an error if the user lacks permission change attributes on the underlying file. It may also return an error in other os-specific unspecified cases.
Examples
use tokio::fs::File; # async fn dox() -> std::io::Result<()> { let file = File::open("foo.txt").await?; let mut perms = file.metadata().await?.permissions(); perms.set_readonly(true); file.set_permissions(perms).await?; # Ok(()) # }fn set_max_buf_size(self: &mut Self, max_buf_size: usize)Set the maximum buffer size for the underlying
AsyncRead/AsyncWriteoperation.Although Tokio uses a sensible default value for this buffer size, this function would be useful for changing that default depending on the situation.
Examples
use tokio::fs::File; use tokio::io::AsyncWriteExt; # async fn dox() -> std::io::Result<()> { let mut file = File::open("foo.txt").await?; // Set maximum buffer size to 8 MiB file.set_max_buf_size(8 * 1024 * 1024); let mut buf = vec![1; 1024 * 1024 * 1024]; // Write the 1 GiB buffer in chunks up to 8 MiB each. file.write_all(&mut buf).await?; # Ok(()) # }
impl AsFd for File
fn as_fd(self: &Self) -> BorrowedFd<'_>
impl AsRawFd for File
fn as_raw_fd(self: &Self) -> RawFd
impl AsyncRead for File
fn poll_read(self: Pin<&mut Self>, cx: &mut Context<'_>, dst: &mut ReadBuf<'_>) -> Poll<Result<()>>
impl AsyncSeek for File
fn start_seek(self: Pin<&mut Self>, pos: SeekFrom) -> Result<()>fn poll_complete(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<u64>>
impl AsyncWrite for File
fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, src: &[u8]) -> Poll<Result<usize>>fn poll_write_vectored(self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &[IoSlice<'_>]) -> Poll<Result<usize, Error>>fn is_write_vectored(self: &Self) -> boolfn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>fn poll_shutdown(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
impl Debug for File
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl Freeze for File
impl From for File
fn from(std: StdFile) -> Self
impl FromRawFd for File
unsafe fn from_raw_fd(fd: RawFd) -> Self
impl RefUnwindSafe for File
impl Send for File
impl Sync for File
impl Unpin for File
impl UnsafeUnpin for File
impl UnwindSafe for File
impl<R> AsyncReadExt for File
impl<S> AsyncSeekExt for File
impl<T> Any for File
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for File
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for File
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for File
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for File
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for File
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for File
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>