Function simplex
fn simplex(max_buf_size: usize) -> (ReadHalf<SimplexStream>, WriteHalf<SimplexStream>)
Creates unidirectional buffer that acts like in memory pipe.
The max_buf_size argument is the maximum amount of bytes that can be
written to a buffer before the it returns Poll::Pending.
Unify reader and writer
The reader and writer half can be unified into a single structure
of SimplexStream that supports both reading and writing or
the SimplexStream can be already created as unified structure
using [SimplexStream::new_unsplit()].
# async