Function sink
fn sink() -> Sink
Creates an instance of an async writer which will successfully consume all data.
All calls to poll_write on the returned instance will return
Poll::Ready(Ok(buf.len())) and the contents of the buffer will not be
inspected.
This is an asynchronous version of std::io::sink.
Examples
use ;
async