Struct Join
struct Join<R, W> { ... }
Joins two values implementing AsyncRead and AsyncWrite into a
single handle.
Implementations
impl<R, W> Join<R, W>
fn into_inner(self: Self) -> (R, W)Splits this
Joinback into itsAsyncReadandAsyncWritecomponents.fn reader(self: &Self) -> &RReturns a reference to the inner reader.
fn writer(self: &Self) -> &WReturns a reference to the inner writer.
fn reader_mut(self: &mut Self) -> &mut RReturns a mutable reference to the inner reader.
fn writer_mut(self: &mut Self) -> &mut WReturns a mutable reference to the inner writer.
fn reader_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>Returns a pinned mutable reference to the inner reader.
fn writer_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>Returns a pinned mutable reference to the inner writer.
impl<'__pin, R, W> Unpin for Join<R, W>
impl<R> AsyncBufReadExt for Join<R, W>
impl<R> AsyncReadExt for Join<R, W>
impl<R, W> AsyncBufRead for Join<R, W>
fn poll_fill_buf(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<&[u8]>>fn consume(self: Pin<&mut Self>, amt: usize)
impl<R, W> AsyncRead for Join<R, W>
fn poll_read(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &mut ReadBuf<'_>) -> Poll<Result<(), Error>>
impl<R, W> AsyncWrite for Join<R, W>
fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8]) -> Poll<Result<usize, Error>>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>fn poll_shutdown(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>fn poll_write_vectored(self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &[IoSlice<'_>]) -> Poll<Result<usize, Error>>fn is_write_vectored(self: &Self) -> bool
impl<R, W> Freeze for Join<R, W>
impl<R, W> RefUnwindSafe for Join<R, W>
impl<R, W> Send for Join<R, W>
impl<R, W> Sync for Join<R, W>
impl<R, W> UnsafeUnpin for Join<R, W>
impl<R, W> UnwindSafe for Join<R, W>
impl<R: $crate::fmt::Debug, W: $crate::fmt::Debug> Debug for Join<R, W>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Join<R, W>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Join<R, W>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Join<R, W>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Join<R, W>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Join<R, W>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Join<R, W>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Join<R, W>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>