Struct Lines

struct Lines<R> { ... }

Reads lines from an AsyncBufRead.

A Lines can be turned into a Stream with LinesStream.

This type is usually created using the lines method.

Implementations

impl<R> Lines<R>

async fn next_line(self: &mut Self) -> Result<Option<String>>

Returns the next line in the stream.

Cancel safety

This method is cancellation safe.

Examples

# use tokio::io::AsyncBufRead;
use tokio::io::AsyncBufReadExt;

# async fn dox(my_buf_read: impl AsyncBufRead + Unpin) -> std::io::Result<()> {
let mut lines = my_buf_read.lines();

while let Some(line) = lines.next_line().await? {
    println!("length = {}", line.len())
}
# Ok(())
# }
fn get_mut(self: &mut Self) -> &mut R

Obtains a mutable reference to the underlying reader.

fn get_ref(self: &mut Self) -> &R

Obtains a reference to the underlying reader.

fn into_inner(self: Self) -> R

Unwraps this Lines<R>, returning the underlying reader.

Note that any leftover data in the internal buffer is lost. Therefore, a following read from the underlying reader may lead to data loss.

impl<R> Lines<R>

fn poll_next_line(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<Option<String>>>

Polls for the next line in the stream.

This method returns:

  • Poll::Pending if the next line is not yet available.
  • Poll::Ready(Ok(Some(line))) if the next line is available.
  • Poll::Ready(Ok(None)) if there are no more lines in this stream.
  • Poll::Ready(Err(err)) if an IO error occurred while reading the next line.

When the method returns Poll::Pending, the Waker in the provided Context is scheduled to receive a wakeup when more bytes become available on the underlying IO resource. Note that on multiple calls to poll_next_line, only the Waker from the Context passed to the most recent call is scheduled to receive a wakeup.

impl<'__pin, R> Unpin for Lines<R>

impl<R> Freeze for Lines<R>

impl<R> RefUnwindSafe for Lines<R>

impl<R> Send for Lines<R>

impl<R> Sync for Lines<R>

impl<R> UnsafeUnpin for Lines<R>

impl<R> UnwindSafe for Lines<R>

impl<R: $crate::fmt::Debug> Debug for Lines<R>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Lines<R>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Lines<R>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Lines<R>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Lines<R>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Lines<R>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Lines<R>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Lines<R>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>