Struct Lines
struct Lines<R> { ... }
Reads lines from an AsyncBufRead.
A Lines can be turned into a Stream with LinesStream.
This type is usually created using the lines method.
Implementations
impl<R> Lines<R>
async fn next_line(self: &mut Self) -> Result<Option<String>>Returns the next line in the stream.
Cancel safety
This method is cancellation safe.
Examples
# use AsyncBufRead; use AsyncBufReadExt; # asyncfn get_mut(self: &mut Self) -> &mut RObtains a mutable reference to the underlying reader.
fn get_ref(self: &mut Self) -> &RObtains a reference to the underlying reader.
fn into_inner(self: Self) -> RUnwraps this
Lines<R>, returning the underlying reader.Note that any leftover data in the internal buffer is lost. Therefore, a following read from the underlying reader may lead to data loss.
impl<R> Lines<R>
fn poll_next_line(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<Option<String>>>Polls for the next line in the stream.
This method returns:
Poll::Pendingif the next line is not yet available.Poll::Ready(Ok(Some(line)))if the next line is available.Poll::Ready(Ok(None))if there are no more lines in this stream.Poll::Ready(Err(err))if an IO error occurred while reading the next line.
When the method returns
Poll::Pending, theWakerin the providedContextis scheduled to receive a wakeup when more bytes become available on the underlying IO resource. Note that on multiple calls topoll_next_line, only theWakerfrom theContextpassed to the most recent call is scheduled to receive a wakeup.
impl<'__pin, R> Unpin for Lines<R>
impl<R> Freeze for Lines<R>
impl<R> RefUnwindSafe for Lines<R>
impl<R> Send for Lines<R>
impl<R> Sync for Lines<R>
impl<R> UnsafeUnpin for Lines<R>
impl<R> UnwindSafe for Lines<R>
impl<R: $crate::fmt::Debug> Debug for Lines<R>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Lines<R>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Lines<R>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Lines<R>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Lines<R>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Lines<R>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Lines<R>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Lines<R>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>