Struct Repeat
struct Repeat { ... }
An async reader which yields one byte over and over and over and over and over and...
This struct is generally created by calling repeat. Please
see the documentation of repeat() for more details.
This is an asynchronous version of std::io::Repeat.
Implementations
impl AsyncRead for Repeat
fn poll_read(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &mut ReadBuf<'_>) -> Poll<Result<()>>
impl Debug for Repeat
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Repeat
impl RefUnwindSafe for Repeat
impl Send for Repeat
impl Sync for Repeat
impl Unpin for Repeat
impl UnsafeUnpin for Repeat
impl UnwindSafe for Repeat
impl<R> AsyncReadExt for Repeat
impl<T> Any for Repeat
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Repeat
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Repeat
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Repeat
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Repeat
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Repeat
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Repeat
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>