Struct Sink
struct Sink { ... }
An async writer which will move data into the void.
This struct is generally created by calling sink. Please
see the documentation of sink() for more details.
This is an asynchronous version of std::io::Sink.
Implementations
impl AsyncWrite for Sink
fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8]) -> Poll<Result<usize, Error>>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>fn poll_shutdown(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
impl Debug for Sink
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Sink
impl RefUnwindSafe for Sink
impl Send for Sink
impl Sync for Sink
impl Unpin for Sink
impl UnsafeUnpin for Sink
impl UnwindSafe for Sink
impl<T> Any for Sink
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Sink
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Sink
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Sink
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Sink
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Sink
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Sink
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>