Struct ReadHalf
struct ReadHalf<'a>(_)
Borrowed read half of a TcpStream, created by split.
Reading from a ReadHalf is usually done using the convenience methods found on the
AsyncReadExt trait.
Implementations
impl ReadHalf<'_>
fn poll_peek(self: &mut Self, cx: &mut Context<'_>, buf: &mut ReadBuf<'_>) -> Poll<Result<usize>>Attempts to receive data on the socket, without removing that data from the queue, registering the current task for wakeup if data is not yet available.
Note that on multiple calls to
poll_peekorpoll_read, only theWakerfrom theContextpassed to the most recent call is scheduled to receive a wakeup.See the
TcpStream::poll_peeklevel documentation for more details.Examples
use tokio::io::{self, ReadBuf}; use tokio::net::TcpStream; use std::future::poll_fn; #[tokio::main] async fn main() -> io::Result<()> { let mut stream = TcpStream::connect("127.0.0.1:8000").await?; let (mut read_half, _) = stream.split(); let mut buf = [0; 10]; let mut buf = ReadBuf::new(&mut buf); poll_fn(|cx| { read_half.poll_peek(cx, &mut buf) }).await?; Ok(()) }async fn peek(self: &mut Self, buf: &mut [u8]) -> Result<usize>Receives data on the socket from the remote address to which it is connected, without removing that data from the queue. On success, returns the number of bytes peeked.
See the
TcpStream::peeklevel documentation for more details.Examples
use tokio::net::TcpStream; use tokio::io::AsyncReadExt; use std::error::Error; #[tokio::main] async fn main() -> Result<(), Box<dyn Error>> { // Connect to a peer let mut stream = TcpStream::connect("127.0.0.1:8080").await?; let (mut read_half, _) = stream.split(); let mut b1 = [0; 10]; let mut b2 = [0; 10]; // Peek at the data let n = read_half.peek(&mut b1).await?; // Read the data assert_eq!(n, read_half.read(&mut b2[..n]).await?); assert_eq!(&b1[..n], &b2[..n]); Ok(()) }The
readmethod is defined on theAsyncReadExttrait.async fn ready(self: &Self, interest: Interest) -> Result<Ready>Waits for any of the requested ready states.
This function is usually paired with
try_read(). It can be used instead ofreadable()to check the returned ready set forReady::READABLEandReady::READ_CLOSEDevents.The function may complete without the socket being ready. This is a false-positive and attempting an operation will return with
io::ErrorKind::WouldBlock. The function can also return with an emptyReadyset, so you should always check the returned value and possibly wait again if the requested states are not set.This function is equivalent to
TcpStream::ready.Cancel safety
This method is cancel safe. Once a readiness event occurs, the method will continue to return immediately until the readiness event is consumed by an attempt to read or write that fails with
WouldBlockorPoll::Pending.async fn readable(self: &Self) -> Result<()>Waits for the socket to become readable.
This function is equivalent to
ready(Interest::READABLE)and is usually paired withtry_read().This function is also equivalent to
TcpStream::ready.Cancel safety
This method is cancel safe. Once a readiness event occurs, the method will continue to return immediately until the readiness event is consumed by an attempt to read that fails with
WouldBlockorPoll::Pending.fn try_read(self: &Self, buf: &mut [u8]) -> Result<usize>Tries to read data from the stream into the provided buffer, returning how many bytes were read.
Receives any pending data from the socket but does not wait for new data to arrive. On success, returns the number of bytes read. Because
try_read()is non-blocking, the buffer does not have to be stored by the async task and can exist entirely on the stack.Usually,
readable()orready()is used with this function.Return
If data is successfully read,
Ok(n)is returned, wherenis the number of bytes read. Ifnis0, then it can indicate one of two scenarios:- The stream's read half is closed and will no longer yield data.
- The specified buffer was 0 bytes in length.
If the stream is not ready to read data,
Err(io::ErrorKind::WouldBlock)is returned.fn try_read_vectored(self: &Self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>Tries to read data from the stream into the provided buffers, returning how many bytes were read.
Data is copied to fill each buffer in order, with the final buffer written to possibly being only partially filled. This method behaves equivalently to a single call to
try_read()with concatenated buffers.Receives any pending data from the socket but does not wait for new data to arrive. On success, returns the number of bytes read. Because
try_read_vectored()is non-blocking, the buffer does not have to be stored by the async task and can exist entirely on the stack.Usually,
readable()orready()is used with this function.Return
If data is successfully read,
Ok(n)is returned, wherenis the number of bytes read.Ok(0)indicates the stream's read half is closed and will no longer yield data. If the stream is not ready to read dataErr(io::ErrorKind::WouldBlock)is returned.fn try_read_buf<B: BufMut>(self: &Self, buf: &mut B) -> Result<usize>Tries to read data from the stream into the provided buffer, advancing the buffer's internal cursor, returning how many bytes were read.
Receives any pending data from the socket but does not wait for new data to arrive. On success, returns the number of bytes read. Because
try_read_buf()is non-blocking, the buffer does not have to be stored by the async task and can exist entirely on the stack.Usually,
readable()orready()is used with this function.Return
If data is successfully read,
Ok(n)is returned, wherenis the number of bytes read.Ok(0)indicates the stream's read half is closed and will no longer yield data. If the stream is not ready to read dataErr(io::ErrorKind::WouldBlock)is returned.fn peer_addr(self: &Self) -> Result<SocketAddr>Returns the remote address that this stream is connected to.
fn local_addr(self: &Self) -> Result<SocketAddr>Returns the local address that this stream is bound to.
impl AsRef for ReadHalf<'_>
fn as_ref(self: &Self) -> &TcpStream
impl AsyncRead for ReadHalf<'_>
fn poll_read(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &mut ReadBuf<'_>) -> Poll<Result<()>>
impl<'a> Debug for ReadHalf<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for ReadHalf<'a>
impl<'a> RefUnwindSafe for ReadHalf<'a>
impl<'a> Send for ReadHalf<'a>
impl<'a> Sync for ReadHalf<'a>
impl<'a> Unpin for ReadHalf<'a>
impl<'a> UnsafeUnpin for ReadHalf<'a>
impl<'a> UnwindSafe for ReadHalf<'a>
impl<R> AsyncReadExt for ReadHalf<'a>
impl<T> Any for ReadHalf<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ReadHalf<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ReadHalf<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ReadHalf<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ReadHalf<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ReadHalf<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ReadHalf<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>