Enum RuntimeFlavor
enum RuntimeFlavor
The flavor of a Runtime.
This is the return type for Handle::runtime_flavor.
Variants
-
CurrentThread The flavor that executes all tasks on the current thread.
-
MultiThread The flavor that executes tasks across multiple threads.
Implementations
impl Debug for RuntimeFlavor
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for RuntimeFlavor
impl Freeze for RuntimeFlavor
impl PartialEq for RuntimeFlavor
fn eq(self: &Self, other: &RuntimeFlavor) -> bool
impl RefUnwindSafe for RuntimeFlavor
impl Send for RuntimeFlavor
impl StructuralPartialEq for RuntimeFlavor
impl Sync for RuntimeFlavor
impl Unpin for RuntimeFlavor
impl UnsafeUnpin for RuntimeFlavor
impl UnwindSafe for RuntimeFlavor
impl<T> Any for RuntimeFlavor
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RuntimeFlavor
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RuntimeFlavor
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for RuntimeFlavor
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for RuntimeFlavor
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RuntimeFlavor
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RuntimeFlavor
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>