Enum tokio::sync::broadcast::error::TryRecvError [−][src]
pub enum TryRecvError {
Empty,
Closed,
Lagged(u64),
}Variants
Empty
The channel is currently empty. There are still active
Sender handles, so data may yet become available.
Closed
There are no more active senders implying no further messages will ever be sent.
Lagged(u64)
Tuple Fields
0: u64The receiver lagged too far behind and has been forcibly disconnected. Attempting to receive again will return the oldest message still retained by the channel.
Includes the number of skipped messages.