Struct OwnedPermit
struct OwnedPermit<T> { ... }
Owned permit to send one value into the channel.
This is identical to the Permit type, except that it moves the sender
rather than borrowing it.
OwnedPermit values are returned by Sender::reserve_owned() and
Sender::try_reserve_owned() and are used to guarantee channel capacity
before generating a message to send.
Implementations
impl<T> OwnedPermit<T>
fn send(self: Self, value: T) -> Sender<T>Sends a value using the reserved capacity.
Capacity for the message has already been reserved. The message is sent to the receiver and the permit is consumed. The operation will succeed even if the receiver half has been closed. See
Receiver::closefor more details on performing a clean shutdown.Unlike
Permit::send, this method returns theSenderfrom which theOwnedPermitwas reserved.Examples
use mpsc; asyncfn release(self: Self) -> Sender<T>Releases the reserved capacity without sending a message, returning the
Sender.Examples
use mpsc; asyncfn same_channel(self: &Self, other: &Self) -> boolReturns
trueif permits belong to the same channel.Examples
use mpsc; asyncfn same_channel_as_sender(self: &Self, sender: &Sender<T>) -> boolReturns
trueif this permit belongs to the same channel as the givenSender.Examples
use mpsc; async
impl<T> Any for OwnedPermit<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for OwnedPermit<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for OwnedPermit<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for OwnedPermit<T>
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl<T> Drop for OwnedPermit<T>
fn drop(self: &mut Self)
impl<T> Freeze for OwnedPermit<T>
impl<T> From for OwnedPermit<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for OwnedPermit<T>
impl<T> Send for OwnedPermit<T>
impl<T> Sync for OwnedPermit<T>
impl<T> Unpin for OwnedPermit<T>
impl<T> UnsafeUnpin for OwnedPermit<T>
impl<T> UnwindSafe for OwnedPermit<T>
impl<T, U> Into for OwnedPermit<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for OwnedPermit<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for OwnedPermit<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>