Struct PermitIterator
struct PermitIterator<'a, T> { ... }
An Iterator of Permit that can be used to hold n slots in the channel.
PermitIterator values are returned by Sender::reserve_many() and Sender::try_reserve_many()
and are used to guarantee channel capacity before generating n messages to send.
Implementations
impl<'a, T> Freeze for PermitIterator<'a, T>
impl<'a, T> Iterator for PermitIterator<'a, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a, T> RefUnwindSafe for PermitIterator<'a, T>
impl<'a, T> Send for PermitIterator<'a, T>
impl<'a, T> Sync for PermitIterator<'a, T>
impl<'a, T> Unpin for PermitIterator<'a, T>
impl<'a, T> UnsafeUnpin for PermitIterator<'a, T>
impl<'a, T> UnwindSafe for PermitIterator<'a, T>
impl<I> IntoIterator for PermitIterator<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for PermitIterator<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PermitIterator<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PermitIterator<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for PermitIterator<'_, T>
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl<T> Drop for PermitIterator<'_, T>
fn drop(self: &mut Self)
impl<T> ExactSizeIterator for PermitIterator<'_, T>
impl<T> From for PermitIterator<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for PermitIterator<'_, T>
impl<T, U> Into for PermitIterator<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PermitIterator<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PermitIterator<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>