Struct OwnedMutexGuard

struct OwnedMutexGuard<T: ?Sized> { ... }

An owned handle to a held Mutex.

This guard is only available from a Mutex that is wrapped in an Arc. It is identical to MutexGuard, except that rather than borrowing the Mutex, it clones the Arc, incrementing the reference count. This means that unlike MutexGuard, it will have the 'static lifetime.

As long as you have this guard, you have exclusive access to the underlying T. The guard internally keeps a reference-counted pointer to the original Mutex, so even if the lock goes away, the guard remains valid.

The lock is automatically released whenever the guard is dropped, at which point lock will succeed yet again.

Implementations

impl<T: ?Sized> OwnedMutexGuard<T>

fn map<U, F>(this: Self, f: F) -> OwnedMappedMutexGuard<T, U>
where
    U: ?Sized,
    F: FnOnce(&mut T) -> &mut U

Makes a new OwnedMappedMutexGuard for a component of the locked data.

This operation cannot fail as the OwnedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMutexGuard::map(...). A method would interfere with methods of the same name on the contents of the locked data.

Examples

use tokio::sync::{Mutex, OwnedMutexGuard};
use std::sync::Arc;

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

# #[tokio::main]
# async fn main() {
let foo = Arc::new(Mutex::new(Foo(1)));

{
    let mut mapped = OwnedMutexGuard::map(foo.clone().lock_owned().await, |f| &mut f.0);
    *mapped = 2;
}

assert_eq!(Foo(2), *foo.lock().await);
# }
fn try_map<U, F>(this: Self, f: F) -> Result<OwnedMappedMutexGuard<T, U>, Self>
where
    U: ?Sized,
    F: FnOnce(&mut T) -> Option<&mut U>

Attempts to make a new OwnedMappedMutexGuard for a component of the locked data. The original guard is returned if the closure returns None.

This operation cannot fail as the OwnedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMutexGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.

Examples

use tokio::sync::{Mutex, OwnedMutexGuard};
use std::sync::Arc;

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

# #[tokio::main]
# async fn main() {
let foo = Arc::new(Mutex::new(Foo(1)));

{
    let mut mapped = OwnedMutexGuard::try_map(foo.clone().lock_owned().await, |f| Some(&mut f.0))
        .expect("should not fail");
    *mapped = 2;
}

assert_eq!(Foo(2), *foo.lock().await);
# }
fn mutex(this: &Self) -> &Arc<Mutex<T>>

Returns a reference to the original Arc<Mutex>.

use std::sync::Arc;
use tokio::sync::{Mutex, OwnedMutexGuard};

async fn unlock_and_relock(guard: OwnedMutexGuard<u32>) -> OwnedMutexGuard<u32> {
    println!("1. contains: {:?}", *guard);
    let mutex: Arc<Mutex<u32>> = OwnedMutexGuard::mutex(&guard).clone();
    drop(guard);
    let guard = mutex.lock_owned().await;
    println!("2. contains: {:?}", *guard);
    guard
}
#
# #[tokio::main]
# async fn main() {
#     let mutex = Arc::new(Mutex::new(0u32));
#     let guard = mutex.lock_owned().await;
#     unlock_and_relock(guard).await;
# }

impl<P, T> Receiver for OwnedMutexGuard<T>

impl<T> Any for OwnedMutexGuard<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for OwnedMutexGuard<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for OwnedMutexGuard<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Freeze for OwnedMutexGuard<T>

impl<T> From for OwnedMutexGuard<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for OwnedMutexGuard<T>

impl<T> Send for OwnedMutexGuard<T>

impl<T> Sync for OwnedMutexGuard<T>

impl<T> ToString for OwnedMutexGuard<T>

fn to_string(self: &Self) -> String

impl<T> Unpin for OwnedMutexGuard<T>

impl<T> UnsafeUnpin for OwnedMutexGuard<T>

impl<T> UnwindSafe for OwnedMutexGuard<T>

impl<T, U> Into for OwnedMutexGuard<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for OwnedMutexGuard<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for OwnedMutexGuard<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: ?Sized + fmt::Debug> Debug for OwnedMutexGuard<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: ?Sized + fmt::Display> Display for OwnedMutexGuard<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: ?Sized> Deref for OwnedMutexGuard<T>

fn deref(self: &Self) -> &<Self as >::Target

impl<T: ?Sized> DerefMut for OwnedMutexGuard<T>

fn deref_mut(self: &mut Self) -> &mut <Self as >::Target

impl<T: ?Sized> Drop for OwnedMutexGuard<T>

fn drop(self: &mut Self)