Struct OwnedMutexGuard
struct OwnedMutexGuard<T: ?Sized> { ... }
An owned handle to a held Mutex.
This guard is only available from a Mutex that is wrapped in an Arc. It
is identical to MutexGuard, except that rather than borrowing the Mutex,
it clones the Arc, incrementing the reference count. This means that
unlike MutexGuard, it will have the 'static lifetime.
As long as you have this guard, you have exclusive access to the underlying
T. The guard internally keeps a reference-counted pointer to the original
Mutex, so even if the lock goes away, the guard remains valid.
The lock is automatically released whenever the guard is dropped, at which
point lock will succeed yet again.
Implementations
impl<T: ?Sized> OwnedMutexGuard<T>
fn map<U, F>(this: Self, f: F) -> OwnedMappedMutexGuard<T, U> where U: ?Sized, F: FnOnce(&mut T) -> &mut UMakes a new
OwnedMappedMutexGuardfor a component of the locked data.This operation cannot fail as the
OwnedMutexGuardpassed in already locked the mutex.This is an associated function that needs to be used as
OwnedMutexGuard::map(...). A method would interfere with methods of the same name on the contents of the locked data.Examples
use ; use Arc; ; # # asyncfn try_map<U, F>(this: Self, f: F) -> Result<OwnedMappedMutexGuard<T, U>, Self> where U: ?Sized, F: FnOnce(&mut T) -> Option<&mut U>Attempts to make a new
OwnedMappedMutexGuardfor a component of the locked data. The original guard is returned if the closure returnsNone.This operation cannot fail as the
OwnedMutexGuardpassed in already locked the mutex.This is an associated function that needs to be used as
OwnedMutexGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.Examples
use ; use Arc; ; # # asyncfn mutex(this: &Self) -> &Arc<Mutex<T>>Returns a reference to the original
Arc<Mutex>.use Arc; use ; async # # # async
impl<P, T> Receiver for OwnedMutexGuard<T>
impl<T> Any for OwnedMutexGuard<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for OwnedMutexGuard<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for OwnedMutexGuard<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for OwnedMutexGuard<T>
impl<T> From for OwnedMutexGuard<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for OwnedMutexGuard<T>
impl<T> Send for OwnedMutexGuard<T>
impl<T> Sync for OwnedMutexGuard<T>
impl<T> ToString for OwnedMutexGuard<T>
fn to_string(self: &Self) -> String
impl<T> Unpin for OwnedMutexGuard<T>
impl<T> UnsafeUnpin for OwnedMutexGuard<T>
impl<T> UnwindSafe for OwnedMutexGuard<T>
impl<T, U> Into for OwnedMutexGuard<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for OwnedMutexGuard<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for OwnedMutexGuard<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized + fmt::Debug> Debug for OwnedMutexGuard<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized + fmt::Display> Display for OwnedMutexGuard<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Deref for OwnedMutexGuard<T>
fn deref(self: &Self) -> &<Self as >::Target
impl<T: ?Sized> DerefMut for OwnedMutexGuard<T>
fn deref_mut(self: &mut Self) -> &mut <Self as >::Target
impl<T: ?Sized> Drop for OwnedMutexGuard<T>
fn drop(self: &mut Self)