Struct TryLockError
struct TryLockError(_)
Error returned from the Mutex::try_lock, RwLock::try_read and
RwLock::try_write functions.
Mutex::try_lock operation will only fail if the mutex is already locked.
RwLock::try_read operation will only fail if the lock is currently held
by an exclusive writer.
RwLock::try_write operation will only fail if the lock is currently held
by any reader or by an exclusive writer.
Implementations
impl Debug for TryLockError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for TryLockError
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl Error for TryLockError
impl Freeze for TryLockError
impl RefUnwindSafe for TryLockError
impl Send for TryLockError
impl Sync for TryLockError
impl Unpin for TryLockError
impl UnsafeUnpin for TryLockError
impl UnwindSafe for TryLockError
impl<T> Any for TryLockError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TryLockError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TryLockError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for TryLockError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for TryLockError
fn to_string(self: &Self) -> String
impl<T, U> Into for TryLockError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TryLockError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TryLockError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>