Struct JoinHandle
struct JoinHandle<T> { ... }
An owned permission to join on a task (await its termination).
This can be thought of as the equivalent of std::thread::JoinHandle
for a Tokio task rather than a thread. Note that the background task
associated with this JoinHandle started running immediately when you
called spawn, even if you have not yet awaited the JoinHandle.
A JoinHandle detaches the associated task when it is dropped, which
means that there is no longer any handle to the task, and no way to join
on it.
This struct is created by the task::spawn and task::spawn_blocking
functions.
Cancel safety
The &mut JoinHandle<T> type is cancel safe. If it is used as the event
in a tokio::select! statement and some other branch completes first,
then it is guaranteed that the output of the task is not lost.
If a JoinHandle is dropped, then the task continues running in the
background and its return value is lost.
Examples
Creation from task::spawn:
use task;
# async
Creation from task::spawn_blocking:
use task;
# async
The generic parameter T in JoinHandle<T> is the return type of the spawned task.
If the return value is an i32, the join handle has type JoinHandle<i32>:
use task;
# async
If the task does not have a return value, the join handle has type JoinHandle<()>:
use task;
# async
Note that handle.await doesn't give you the return type directly. It is wrapped in a
Result because panics in the spawned task are caught by Tokio. The ? operator has
to be double chained to extract the returned value:
use task;
use io;
async
If the task panics, the error is a JoinError that contains the panic:
use task;
use io;
use panic;
async
Child being detached and outliving its parent:
use tokio::task;
use tokio::time;
use std::time::Duration;
# #[tokio::main] async fn main() {
let original_task = task::spawn(async {
let _detached_task = task::spawn(async {
// Here we sleep to make sure that the first task returns before.
time::sleep(Duration::from_millis(10)).await;
// This will be called, even though the JoinHandle is dropped.
println!("♫ Still alive ♫");
});
});
original_task.await.expect("The task being joined has panicked");
println!("Original task is joined.");
// We make sure that the new task has time to run, before the main
// task returns.
time::sleep(Duration::from_millis(1000)).await;
# }
Implementations
impl<T> JoinHandle<T>
fn abort(self: &Self)Abort the task associated with the handle.
Awaiting a cancelled task might complete as usual if the task was already completed at the time it was cancelled, but most likely it will fail with a cancelled
JoinError.Be aware that tasks spawned using
spawn_blockingcannot be aborted because they are not async. If you callaborton aspawn_blockingtask, then this will not have any effect, and the task will continue running normally. The exception is if the task has not started running yet; in that case, callingabortmay prevent the task from starting.See also the module level docs for more information on cancellation.
use time; # # asyncfn is_finished(self: &Self) -> boolChecks if the task associated with this
JoinHandlehas finished.Please note that this method can return
falseeven ifaborthas been called on the task. This is because the cancellation process may take some time, and this method does not returntrueuntil it has completed.use time; # # asyncfn abort_handle(self: &Self) -> AbortHandleReturns a new
AbortHandlethat can be used to remotely abort this task.Awaiting a task cancelled by the
AbortHandlemight complete as usual if the task was already completed at the time it was cancelled, but most likely it will fail with a cancelledJoinError.use ; # # asyncfn id(self: &Self) -> IdReturns a task ID that uniquely identifies this task relative to other currently spawned tasks.
impl<F> IntoFuture for JoinHandle<T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for JoinHandle<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for JoinHandle<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for JoinHandle<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for JoinHandle<T>
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl<T> Drop for JoinHandle<T>
fn drop(self: &mut Self)
impl<T> Freeze for JoinHandle<T>
impl<T> From for JoinHandle<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Future for JoinHandle<T>
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>
impl<T> RefUnwindSafe for JoinHandle<T>
impl<T> Unpin for JoinHandle<T>
impl<T> UnsafeUnpin for JoinHandle<T>
impl<T> UnwindSafe for JoinHandle<T>
impl<T, U> Into for JoinHandle<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for JoinHandle<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for JoinHandle<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>