Struct Instant
struct Instant { ... }
A measurement of a monotonically nondecreasing clock.
Opaque and useful only with Duration.
Instants are always guaranteed to be no less than any previously measured instant when created, and are often useful for tasks such as measuring benchmarks or timing how long an operation takes.
Note, however, that instants are not guaranteed to be steady. In other words, each tick of the underlying clock may not be the same length (e.g. some seconds may be longer than others). An instant may jump forwards or experience time dilation (slow down or speed up), but it will never go backwards.
Instants are opaque types that can only be compared to one another. There is no method to get "the number of seconds" from an instant. Instead, it only allows measuring the duration between two instants (or comparing two instants).
The size of an Instant struct may vary depending on the target operating
system.
Note
This type wraps the inner std variant and is used to align the Tokio
clock for uses of now(). This can be useful for testing where you can
take advantage of time::pause() and time::advance().
Implementations
impl Instant
fn now() -> InstantReturns an instant corresponding to "now".
Examples
use Instant; let now = now;fn from_std(std: Instant) -> InstantCreate a
tokio::time::Instantfrom astd::time::Instant.fn into_std(self: Self) -> InstantConvert the value into a
std::time::Instant.fn duration_since(self: &Self, earlier: Instant) -> DurationReturns the amount of time elapsed from another instant to this one, or zero duration if that instant is later than this one.
fn checked_duration_since(self: &Self, earlier: Instant) -> Option<Duration>Returns the amount of time elapsed from another instant to this one, or None if that instant is later than this one.
Examples
use ; asyncfn saturating_duration_since(self: &Self, earlier: Instant) -> DurationReturns the amount of time elapsed from another instant to this one, or zero duration if that instant is later than this one.
Examples
use ; asyncfn elapsed(self: &Self) -> DurationReturns the amount of time elapsed since this instant was created, or zero duration if this instant is in the future.
Examples
use ; asyncfn checked_add(self: &Self, duration: Duration) -> Option<Instant>Returns
Some(t)wheretis the timeself + durationiftcan be represented asInstant(which means it's inside the bounds of the underlying data structure),Noneotherwise.fn checked_sub(self: &Self, duration: Duration) -> Option<Instant>Returns
Some(t)wheretis the timeself - durationiftcan be represented asInstant(which means it's inside the bounds of the underlying data structure),Noneotherwise.
impl Add for Instant
fn add(self: Self, other: Duration) -> Instant
impl AddAssign for Instant
fn add_assign(self: &mut Self, rhs: Duration)
impl Clone for Instant
fn clone(self: &Self) -> Instant
impl Copy for Instant
impl Debug for Instant
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl Eq for Instant
impl Freeze for Instant
impl From for Instant
fn from(time: Instant) -> Instant
impl Hash for Instant
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for Instant
fn cmp(self: &Self, other: &Instant) -> Ordering
impl PartialEq for Instant
fn eq(self: &Self, other: &Instant) -> bool
impl PartialOrd for Instant
fn partial_cmp(self: &Self, other: &Instant) -> Option<Ordering>
impl RefUnwindSafe for Instant
impl Send for Instant
impl StructuralPartialEq for Instant
impl Sub for Instant
fn sub(self: Self, rhs: Duration) -> Instant
impl Sub for Instant
fn sub(self: Self, rhs: Instant) -> Duration
impl SubAssign for Instant
fn sub_assign(self: &mut Self, rhs: Duration)
impl Sync for Instant
impl Unpin for Instant
impl UnsafeUnpin for Instant
impl UnwindSafe for Instant
impl<T> Any for Instant
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Instant
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Instant
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Instant
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Instant
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Instant
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Instant
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Instant
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Instant
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>