Struct Timeout
struct Timeout<T> { ... }
Future returned by timeout and timeout_at.
Implementations
impl<T> Timeout<T>
fn get_ref(self: &Self) -> &TGets a reference to the underlying value in this timeout.
fn get_mut(self: &mut Self) -> &mut TGets a mutable reference to the underlying value in this timeout.
fn into_inner(self: Self) -> TConsumes this timeout, returning the underlying value.
impl<'__pin, T> Unpin for Timeout<T>
impl<F> IntoFuture for Timeout<T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for Timeout<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Timeout<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Timeout<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for Timeout<T>
impl<T> From for Timeout<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Future for Timeout<T>
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>
impl<T> RefUnwindSafe for Timeout<T>
impl<T> Send for Timeout<T>
impl<T> Sync for Timeout<T>
impl<T> UnsafeUnpin for Timeout<T>
impl<T> UnwindSafe for Timeout<T>
impl<T, U> Into for Timeout<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Timeout<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Timeout<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::fmt::Debug> Debug for Timeout<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result